from django.db import models

# Create your models here.

class Category(models.Model):
    label = models.CharField(max_length=255)
    parent = models.ForeignKey('self', on_delete=models.CASCADE, null=True)
    def children(self):
        return Category.objects.filter(parent=self.id)
    
class Channel(models.Model):
    label = models.CharField(max_length=255)

class Role(models.Model):
    label = models.CharField(max_length=255)

class Tag(models.Model):
    label = models.CharField(max_length=255)

class User(models.Model):
    FEMALE = 1
    MALE = 2
    UNSPECIFIED = 0
    GENDER_CHOICES = [(UNSPECIFIED, 'Unspecified'), (FEMALE, 'Female'), (MALE, 'Male'), ]
    first_name = models.CharField('First name', max_length=255)
    last_name = models.CharField('Last name', max_length=255)
    gender = models.IntegerField(default=UNSPECIFIED, choices = GENDER_CHOICES)
    name_prefix = models.CharField('Salutation', max_length=255)
    username = models.CharField('User name', max_length=255)
    password = models.CharField(max_length=255)
    lifePartner = models.OneToOneField('self', on_delete=models.CASCADE, verbose_name='Life partner', null=True, blank=True)
    category = models.ManyToManyField(Category)
    role = models.ManyToManyField(Role)
    friend = models.ManyToManyField('self')
    def assembleDisplayName(self):
        displayName = ''
        if self.gender == self.MALE:
            displayName += 'Mr.'
        if self.gender == self.FEMALE:
            displayName += 'Mrs.'
        if self.name_prefix != '':
            displayName = self.name_prefix
        displayName += ' ' + self.first_name + ' ' + self.last_name
        return displayName

class UserInfo(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, primary_key=True)
    signUpDate = models.DateTimeField('Date published')
    signOffDate = models.DateTimeField('Date published')

class ContactData(models.Model):
    user = models.OneToOneField(User, on_delete=models.CASCADE, primary_key=True)
    email = models.EmailField(max_length=255)
    phone = models.CharField(max_length=255)

class Post(models.Model):
    user = models.ForeignKey(User, on_delete=models.CASCADE)
    category = models.ForeignKey(Category, on_delete=models.CASCADE, null=True, blank=True)
    tag = models.ManyToManyField(Tag)
    title = models.CharField(max_length=255)
    content = models.TextField()

class VideoPost(Post):
    videoURL = models.CharField(max_length=255)

class ImagePost(Post):
    imageURL = models.CharField(max_length=255)
