from django.shortcuts import render
from django.template import loader

# Create your views here.
from django.http import HttpResponse, HttpResponseRedirect
from django.urls import reverse
from .models import Post, Tag, User

def index(request):
    posts = Post.objects.all()
    context = {
        'posts': posts,
    }
    return render(request, 'djtalk/index.html', context)
    
    
def post(request, post_id):
    post = Post.objects.get(id=post_id)
    name = post.user.assembleDisplayName()
    context = {
        'post': post,
        'name': name,
        'category': post.category,
        'tags': post.tag,
    }
    return render(request, 'djtalk/post.html', context)

def tag(request, label):
    context = {
        'label': label,
        'posts': Tag.objects.get(label=label).post_set.all(),
    }
    return render(request, 'djtalk/tag.html', context)
    
def user(request, user_id):
    user = User.objects.get(id=user_id)
    categories = user.category.all()
    children = {}
    for category in categories:
        id = category.id
        children[id] = category.children()
    context = {
        'name': user.assembleDisplayName(),
        'friends' : user.friend.all(),
        'lifePartner' : user.lifePartner,
        'posts': user.post_set.all(),
        'categories' : categories,
        'children' : children,
    }
    return render(request, 'djtalk/user.html', context)

def edit(request, post_id):
    post = Post.objects.get(pk=post_id)
    if post.user.first_name != "Petar":
        raise Http404("Not allowed to edit post!")
    return render(request, 'djtalk/edit.html', {'post': post})

def editProcess(request):
    post = Post.objects.get(id=request.POST['id'])
    if post.user.first_name != "Petar":
        raise Http404("Not allowed to edit post!")
    post.title = request.POST['title']
    post.content = request.POST['text']
    post.save()
    return HttpResponseRedirect(reverse('djtalk:post', args=(post.id,)))

def add(request):
    return render(request, 'djtalk/add.html', {})

def addProcess(request):
    post = Post()
    post.title = request.POST['title']
    post.content = request.POST['text']
    post.user = User.objects.get(id=request.POST['id'])
    post.save()
    return HttpResponseRedirect(reverse('djtalk:user', args=(post.user.id,)))

def delete(request, post_id):
    post = Post.objects.get(id=post_id)
    user_id = post.user.id
    if post.user.first_name != "Petar":
        raise Http404("Not allowed to delete post!")
    post.delete()
    return HttpResponseRedirect(reverse('djtalk:user', args=(user_id,)))
